@@ -14,14 +14,14 @@
 
 from dataclasses import dataclass
 
-"""
-Represents an error in an API call
-"""
 @dataclass
 class ErrorResult:
-    type: str
-    title: str
-    status: int
-    detail: str
-    instance: str
+    """
+    Represents an error in an API call
+    """
+    type: str | None
+    title: str | None
+    status: int | None
+    detail: str | None
+    instance: str | None
 
