@@ -1,14 +1,13 @@
 #
-# Lockstep Software Development Kit for Python
+# Lockstep Platform SDK for Python
 #
 # (c) 2021-2022 Lockstep, Inc.
 #
 # For the full copyright and license information, please view the LICENSE
 # file that was distributed with this source code.
 #
-# @author     Ted Spence <tspence@lockstep.io>
+# @author     Lockstep Network <support@lockstep.io>
 # @copyright  2021-2022 Lockstep, Inc.
-# @version    2022.3
 # @link       https://github.com/Lockstep-Network/lockstep-sdk-python
 #
 
@@ -17,9 +16,13 @@ from dataclasses import dataclass
 
 @dataclass
 class ActivityXRefModel:
-    activityXRefId: str = None
-    activityId: str = None
-    groupKey: str = None
-    tableKey: str = None
-    objectKey: str = None
+    """
+    Represents links between an Activity and another record.
+    """
+
+    activityXRefId: str | None = None
+    activityId: str | None = None
+    groupKey: str | None = None
+    tableKey: str | None = None
+    objectKey: str | None = None
 
