@@ -1,28 +1,28 @@
 #
-# Lockstep Software Development Kit for Python
+# Lockstep Platform SDK for Python
 #
 # (c) 2021-2022 Lockstep, Inc.
 #
 # For the full copyright and license information, please view the LICENSE
 # file that was distributed with this source code.
 #
-# @author     Ted Spence <tspence@lockstep.io>
+# @author     Lockstep Network <support@lockstep.io>
 # @copyright  2021-2022 Lockstep, Inc.
-# @version    2022.3
 # @link       https://github.com/Lockstep-Network/lockstep-sdk-python
 #
 
 
 from dataclasses import dataclass
 
-"""
-Aggregated Attachment status information.
-"""
 @dataclass
 class AttachmentHeaderInfoModel:
-    groupKey: str = None
-    companyId: str = None
-    totalAttachments: int = None
-    totalArchived: int = None
-    totalActive: int = None
+    """
+    Aggregated Attachment status information.
+    """
+
+    groupKey: str | None = None
+    companyId: str | None = None
+    totalAttachments: int | None = None
+    totalArchived: int | None = None
+    totalActive: int | None = None
 
