@@ -1,25 +1,25 @@
 #
-# Lockstep Software Development Kit for Python
+# Lockstep Platform SDK for Python
 #
 # (c) 2021-2022 Lockstep, Inc.
 #
 # For the full copyright and license information, please view the LICENSE
 # file that was distributed with this source code.
 #
-# @author     Ted Spence <tspence@lockstep.io>
+# @author     Lockstep Network <support@lockstep.io>
 # @copyright  2021-2022 Lockstep, Inc.
-# @version    2022.3
 # @link       https://github.com/Lockstep-Network/lockstep-sdk-python
 #
 
 
 from dataclasses import dataclass
 
-"""
-Input format used for bulk conversion route
-"""
 @dataclass
 class BulkCurrencyConversionModel:
-    date: str = None
-    sourceCurrency: str = None
+    """
+    Input format used for bulk conversion route
+    """
+
+    date: str | None = None
+    sourceCurrency: str | None = None
 
