@@ -1,27 +1,27 @@
 #
-# Lockstep Software Development Kit for Python
+# Lockstep Platform SDK for Python
 #
 # (c) 2021-2022 Lockstep, Inc.
 #
 # For the full copyright and license information, please view the LICENSE
 # file that was distributed with this source code.
 #
-# @author     Ted Spence <tspence@lockstep.io>
+# @author     Lockstep Network <support@lockstep.io>
 # @copyright  2021-2022 Lockstep, Inc.
-# @version    2022.3
 # @link       https://github.com/Lockstep-Network/lockstep-sdk-python
 #
 
 
 from dataclasses import dataclass
 
-"""
-Represents a currency rate for specific currencies and date
-"""
 @dataclass
 class CurrencyRateModel:
-    sourceCurrency: str = None
-    destinationCurrency: str = None
-    date: str = None
-    currencyRate: float = None
+    """
+    Represents a currency rate for specific currencies and date
+    """
+
+    sourceCurrency: str | None = None
+    destinationCurrency: str | None = None
+    date: str | None = None
+    currencyRate: float | None = None
 
