@@ -1,14 +1,13 @@
 #
-# Lockstep Software Development Kit for Python
+# Lockstep Platform SDK for Python
 #
 # (c) 2021-2022 Lockstep, Inc.
 #
 # For the full copyright and license information, please view the LICENSE
 # file that was distributed with this source code.
 #
-# @author     Ted Spence <tspence@lockstep.io>
+# @author     Lockstep Network <support@lockstep.io>
 # @copyright  2021-2022 Lockstep, Inc.
-# @version    2022.3
 # @link       https://github.com/Lockstep-Network/lockstep-sdk-python
 #
 
@@ -16,11 +15,12 @@
 from dataclasses import dataclass
 from lockstep.models.connectorinfomodel import ConnectorInfoModel
 
-"""
-Represents the ERP object sent in a provisioning request
-"""
 @dataclass
 class ErpInfoModel:
-    appId: str = None
-    data: ConnectorInfoModel = None
+    """
+    Represents the ERP object sent in a provisioning request
+    """
+
+    appId: str | None = None
+    data: ConnectorInfoModel | None = None
 
