@@ -1,26 +1,26 @@
 #
-# Lockstep Software Development Kit for Python
+# Lockstep Platform SDK for Python
 #
 # (c) 2021-2022 Lockstep, Inc.
 #
 # For the full copyright and license information, please view the LICENSE
 # file that was distributed with this source code.
 #
-# @author     Ted Spence <tspence@lockstep.io>
+# @author     Lockstep Network <support@lockstep.io>
 # @copyright  2021-2022 Lockstep, Inc.
-# @version    2022.3
 # @link       https://github.com/Lockstep-Network/lockstep-sdk-python
 #
 
 
 from dataclasses import dataclass
 
-"""
-Model containing information about a user for the invite/onboarding 
-process.
-"""
 @dataclass
 class InviteDataModel:
-    email: str = None
-    userStatus: str = None
+    """
+    Model containing information about a user for the invite/onboarding
+    process.
+    """
+
+    email: str | None = None
+    userStatus: str | None = None
 
