@@ -1,14 +1,13 @@
 #
-# Lockstep Software Development Kit for Python
+# Lockstep Platform SDK for Python
 #
 # (c) 2021-2022 Lockstep, Inc.
 #
 # For the full copyright and license information, please view the LICENSE
 # file that was distributed with this source code.
 #
-# @author     Ted Spence <tspence@lockstep.io>
+# @author     Lockstep Network <support@lockstep.io>
 # @copyright  2021-2022 Lockstep, Inc.
-# @version    2022.3
 # @link       https://github.com/Lockstep-Network/lockstep-sdk-python
 #
 
@@ -16,13 +15,14 @@
 from dataclasses import dataclass
 from lockstep.models.useraccountmodel import UserAccountModel
 
-"""
-Model from the User invite process
-"""
 @dataclass
 class InviteModel:
-    email: str = None
-    success: bool = None
-    invitedUser: UserAccountModel = None
-    errorMessage: str = None
+    """
+    Model from the User invite process
+    """
+
+    email: str | None = None
+    success: bool | None = None
+    invitedUser: UserAccountModel | None = None
+    errorMessage: str | None = None
 
