@@ -1,28 +1,28 @@
 #
-# Lockstep Software Development Kit for Python
+# Lockstep Platform SDK for Python
 #
 # (c) 2021-2022 Lockstep, Inc.
 #
 # For the full copyright and license information, please view the LICENSE
 # file that was distributed with this source code.
 #
-# @author     Ted Spence <tspence@lockstep.io>
+# @author     Lockstep Network <support@lockstep.io>
 # @copyright  2021-2022 Lockstep, Inc.
-# @version    2022.3
 # @link       https://github.com/Lockstep-Network/lockstep-sdk-python
 #
 
 
 from dataclasses import dataclass
 
-"""
-Represents leads for creating new ERP connectors
-"""
 @dataclass
 class LeadModel:
-    leadId: str = None
-    name: str = None
-    company: str = None
-    email: str = None
-    erpSystem: str = None
+    """
+    Represents leads for creating new ERP connectors
+    """
+
+    leadId: str | None = None
+    name: str | None = None
+    company: str | None = None
+    email: str | None = None
+    erpSystem: str | None = None
 
