@@ -1,30 +1,26 @@
 #
-# Lockstep Software Development Kit for Python
+# Lockstep Platform SDK for Python
 #
 # (c) 2021-2022 Lockstep, Inc.
 #
 # For the full copyright and license information, please view the LICENSE
 # file that was distributed with this source code.
 #
-# @author     Ted Spence <tspence@lockstep.io>
+# @author     Lockstep Network <support@lockstep.io>
 # @copyright  2021-2022 Lockstep, Inc.
-# @version    2022.3
 # @link       https://github.com/Lockstep-Network/lockstep-sdk-python
 #
 
 
 from dataclasses import dataclass
 from lockstep.models.erpinfomodel import ErpInfoModel
-from lockstep.models.companymodel import CompanyModel
 
-"""
-Represents the data sent during the onboarding flow
-"""
 @dataclass
 class ProvisioningModel:
-    fullName: str = None
-    timeZone: str = None
-    defaultCurrency: str = None
-    erp: ErpInfoModel = None
-    company: CompanyModel = None
+    """
+    Represents the data sent during the onboarding flow
+    """
+
+    fullName: str | None = None
+    erp: ErpInfoModel | None = None
 
