@@ -1,26 +1,26 @@
 #
-# Lockstep Software Development Kit for Python
+# Lockstep Platform SDK for Python
 #
 # (c) 2021-2022 Lockstep, Inc.
 #
 # For the full copyright and license information, please view the LICENSE
 # file that was distributed with this source code.
 #
-# @author     Ted Spence <tspence@lockstep.io>
+# @author     Lockstep Network <support@lockstep.io>
 # @copyright  2021-2022 Lockstep, Inc.
-# @version    2022.3
 # @link       https://github.com/Lockstep-Network/lockstep-sdk-python
 #
 
 
 from dataclasses import dataclass
 
-"""
-State model for ISO-3166-2
-"""
 @dataclass
 class StateModel:
-    name: str = None
-    alpha2: str = None
-    aliases: str = None
+    """
+    State model for ISO-3166-2
+    """
+
+    name: str | None = None
+    alpha2: str | None = None
+    aliases: str | None = None
 
