@@ -1,28 +1,28 @@
 #
-# Lockstep Software Development Kit for Python
+# Lockstep Platform SDK for Python
 #
 # (c) 2021-2022 Lockstep, Inc.
 #
 # For the full copyright and license information, please view the LICENSE
 # file that was distributed with this source code.
 #
-# @author     Ted Spence <tspence@lockstep.io>
+# @author     Lockstep Network <support@lockstep.io>
 # @copyright  2021-2022 Lockstep, Inc.
-# @version    2022.3
 # @link       https://github.com/Lockstep-Network/lockstep-sdk-python
 #
 
 
 from dataclasses import dataclass
 
-"""
-Contains information about a sync process for an entity.
-"""
 @dataclass
 class SyncEntityResultModel:
-    insertCount: int = None
-    updateCount: int = None
-    skipCount: int = None
-    errorCount: int = None
-    errors: object = None
+    """
+    Contains information about a sync process for an entity.
+    """
+
+    insertCount: int | None = None
+    updateCount: int | None = None
+    skipCount: int | None = None
+    errorCount: int | None = None
+    errors: object | None = None
 
