@@ -1,24 +1,24 @@
 #
-# Lockstep Software Development Kit for Python
+# Lockstep Platform SDK for Python
 #
 # (c) 2021-2022 Lockstep, Inc.
 #
 # For the full copyright and license information, please view the LICENSE
 # file that was distributed with this source code.
 #
-# @author     Ted Spence <tspence@lockstep.io>
+# @author     Lockstep Network <support@lockstep.io>
 # @copyright  2021-2022 Lockstep, Inc.
-# @version    2022.3
 # @link       https://github.com/Lockstep-Network/lockstep-sdk-python
 #
 
 
 from dataclasses import dataclass
 
-"""
-Model used to submit a transfer ownership request
-"""
 @dataclass
 class TransferOwnerSubmitModel:
-    targetUserId: str = None
+    """
+    Model used to submit a transfer ownership request
+    """
+
+    targetUserId: str | None = None
 
